#simulate three graphs using the igraph package for further comparison 
library(igraph)

#create an Erdos-Renyi graph
g1<-erdos.renyi.game(30,0.3)

#create a scale-free graph 
g2<-sample_pa(30,power=2.5,directed=F)

#create Watts-Strogatz graph
g3<-sample_smallworld(2,5,3,0.3)

#plot the 3 graphs created
plot(g1,main="Erdos-Renyi Graph")
plot(g2,main="Scale-Free Graph")
plot(g3,main="Watts-Strogatz Graph")

#load TDA package
library(TDAstats)

#get adjacency matrices
m1<-as.matrix(get.adjacency(g1))
m2<-as.matrix(get.adjacency(g2))
m3<-as.matrix(get.adjacency(g3))

#compute persistent homology
d1<-calculate_homology(m1, dim = 2, format = "cloud")
d2<-calculate_homology(m2, dim = 2, format = "cloud")
d3<-calculate_homology(m3, dim = 2, format = "cloud")

#plot persistence diagrams
plot_persist(d1) 
plot_persist(d2)
plot_persist(d3)

#compute distances among graphs
w1<-phom.dist(d1,d2,limit.num=0)
w2<-phom.dist(d1,d3,limit.num=0)
w3<-phom.dist(d2,d3,limit.num=0)

#get Wasserstein distance between random graphs with the same structure
ww<-rep(NA,100)

for (i in 1:100){
g1<-erdos.renyi.game(30,0.3)
g2<-erdos.renyi.game(30,0.3)
m1<-as.matrix(get.adjacency(g1))
m2<-as.matrix(get.adjacency(g2))
d1<-calculate_homology(m1, dim = 2, format = "cloud")
d2<-calculate_homology(m2, dim = 2, format = "cloud")
ww[i]<- phom.dist(d1,d2,limit.num=0)}

#compute 95% confidence intervals from the simulated null distribution
quantile(ww,c(0.025,0.975))
