#create data 
a<-rbinom(100,4,0.2)
b<-rbinom(100,1,0.5)
c<-rbinom(100,2,0.1)
d<-rbinom(100,2,0.2)
e<-rbinom(100,1,0.3)
f<-rbinom(100,1,0.8)
mydata<-as.data.frame(cbind(a,b,c,d,e,f))

#Create distance matrices using different distance metrics
m1<-dist(mydata,"manhattan",upper=T,diag=T)
m2<-dist(mydata,"minkowski",p=10,upper=T,diag=T) 
m3<-dist(mydata,"manhattan",upper=T,diag=T)

#Reduce dimensionality with MDS to 2 dimensions
c1<-cmdscale(m1,k=2)
c2<-cmdscale(m2,k=2)
c3<-cmdscale(m3,k=2)

#Plot results
plot(c1,xlab="Coordinate 1",ylab="Coordinate 2",main="Euclidean Distance MDS 
Results")
plot(c2,xlab="Coordinate 1",ylab="Coordinate 2",main="Minkowski p=10 Distance 
MDS Results")
plot(c3,xlab="Coordinate 1",ylab="Coordinate 2",main="Manhattan Distance MDS 
Results")

#Create Isomap projections of the data generated in script 5-6
library(vegan)

i1<-scores(isomap(dist(mydata),ndim=2,k=5))
i2<-scores(isomap(dist(mydata),ndim=2,k=10))
i3<-scores(isomap(dist(mydata),ndim=2,k=20))

#Plot results 
plot(i1,xlab="Coordinate 1",ylab="Coordinate 2",main="K=5 Isomap Results")
plot(i2,xlab="Coordinate 1",ylab="Coordinate 2",main="K=10 Isomap Results")
plot(i3,xlab="Coordinate 1",ylab="Coordinate 2",main="K=20 Isomap Results")

#Install package
library(devtools)
install_local("~/Downloads/lle.tar")

#Create LLE projections of the data generated in script 5-6
library(lle)

l1<-lle(mydata,m=2,k=5)
l2<-lle(mydata,m=2,k=10)
l3<-lle(mydata,m=2,k=20)

#Plot results 
plot(l1$Y,xlab="Coordinate 1",ylab="Coordinate 2",main="K=5 LLE Results")
plot(l2$Y,xlab="Coordinate 1",ylab="Coordinate 2",main="K=10 LLE Results")
plot(l3$Y,xlab="Coordinate 1",ylab="Coordinate 2",main="K=20 LLE Results")

#Create t-SNE projections of the data generated in Listing 5-7
library(Rtsne)
library(dimRed)

t1<-getDimRedData(embed(mydata,"tSNE",ndim=2,perplexity=5))
t2<-getDimRedData(embed(mydata,"tSNE",ndim=2,perplexity=15))
t3<-getDimRedData(embed(mydata,"tSNE",ndim=2,perplexity=25))

#Plot results 
plot(as.data.frame(t1),xlab="Coordinate 1",ylab="Coordinate 
2",main="Perplexity=5 t-SNE Results")
plot(as.data.frame(t2),xlab="Coordinate 1",ylab="Coordinate 
2",main="Perplexity=15 t-SNE Results")
plot(as.data.frame(t3),xlab="Coordinate 1",ylab="Coordinate 
2",main="Perplexity=25 t-SNE Results")
